function h = odeAbsComp(fbox,expr)
%ODEABSCOMP Compute the absolute stability region.
%  PURPOSE
%     It computes the absolute stability region of the ode scheme.
%
%  SYNTAX
%     odeAbsComp(fbox,expr)
%     h = odeAbsComp(fbox,expr)
%
%  INPUT
%     fbox  : The computation box of the form [xmin xmax ymin ymax]
%     expr  : The stability expression in x and y variables
%
%  OUTPUT
%     h     : Additional handles to the plotted objects
%
%  See also NUMODE.

%  AUTHOR : M. Venturin


% Define the computational grid
xmin = fbox(1); xmax = fbox(2);
ymin = fbox(3); ymax = fbox(4);
xstep = (xmax-xmin)/400; ystep = (ymax-ymin)/400;
[x,y] = meshgrid(xmin:xstep:xmax,ymin:ystep:ymax);

% Evaluate stability expression
% Re(h lambda) = x(i) , Im(h lambda) = y(i)
eval(['z=',expr,';']);
z = double(~z);

% Draw stability region
[c,hh] = contourf(x,y,z,1);
colormap((gray+1)/2); grid off; axis square;
hold on
hf = line([xmin,xmax],[0,0]); set(hf,'Color','k'); hh = [hh;hf];
hf = line([0,0],[ymin,ymax]); set(hf,'Color','k'); hh = [hh;hf];
hold off
xlabel('Re(h\lambda)'); ylabel('Im(h\lambda)');
title('Absolute stability region');

% process output paramters
if nargout
   h = hh;
end
