function h = odeErrorOp(hmax,emax,p)
%ODEERROROP Plot the behaviour of the method O(h^p).
%  PURPOSE
%     It plot the behaviour of the ode method in log-log scale.
%     Error O(h^p) => e = C*h^p => log e = p*log(h)+log(C)
%
%  SYNTAX
%     odeErrorOp(hmax,emax,p)
%     h = odeErrorOp(hmax,emax,p)
%
%  INPUT
%     hmax  : Array vector of stepsize
%     emax  : Array vector of error
%
%  OUTPUT
%     h     : Additional handles to the plotted objects
%
%  See also NUMODE.

%  AUTHOR : M. Venturin


% drawing
hh = loglog(hmax,emax,'k*-');
title(['Error O(h^',num2str(p),')']);
axis square

% drawing line
x1 = hmax(floor(length(hmax)/2));
y1 = emax(end);

x2 = x1*10;
y2 = y1;

x3 = x2;
y3 = y1*(10^p);

hold on
line([x1 x2],[y1 y2]);
line([x1 x3],[y1 y3]);
line([x2 x3],[y2 y3]);
hold off

% process output
if nargout
   h = hh;
end
