function [t,y] = odeEuler(odefun,tspan,y0,h,varargin)
%ODEEULER The Euler's method for ODE.
%  PURPOSE
%     It implements the Euler's method for ode.
%
%  SYNTAX
%     [t,y] = odeEuler(odefun,tspan,y0,h)
%     [t,y] = odeEuler(odefun,tspan,y0,h,P1,...)
%
%  INPUT
%     odefun   : The ode function
%     tspan    : The starting and ending simulation time
%     y0       : The initial condition
%     h        : The stepsize
%     P1       : Optional function parameter
%
%  OUTPUT
%     t        : The time solution vector
%     y        : The solution vector
%
%  See also ODEEULERD1, NUMODE.

%  AUTHOR : M. Venturin


t = (tspan(1):h:tspan(2))';   % allocate memory for t
n = length(t);                % number of elements
y = zeros(n,1);               % allocate memory for y
y(1) = y0;                    % initial condition

% main loop
for j=1:n-1
   y(j+1) = y(j)+h*feval(odefun,t(j),y(j),varargin{:});
end
